print("import: 'google'")
import google

print("import: 'google.protobuf'")
import google.protobuf

print("import: 'google.protobuf.descriptor'")
import google.protobuf.descriptor

print("import: 'google.protobuf.internal'")
import google.protobuf.internal

print("import: 'google.protobuf.pyext'")
import google.protobuf.pyext

print("import: 'google.protobuf.pyext._message'")
import google.protobuf.pyext._message

print("import: 'google.protobuf.util'")
import google.protobuf.util

print("import: 'google.protobuf.compiler'")
import google.protobuf.compiler

