# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/protobuf/util/json_format_proto3.proto
# Protobuf Python Version: 4.25.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.protobuf import unittest_pb2 as google_dot_protobuf_dot_unittest__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-google/protobuf/util/json_format_proto3.proto\x12\x06proto3\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/duration.proto\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1egoogle/protobuf/unittest.proto\"\x1c\n\x0bMessageType\x12\r\n\x05value\x18\x01 \x01(\x05\"\x94\x05\n\x0bTestMessage\x12\x12\n\nbool_value\x18\x01 \x01(\x08\x12\x13\n\x0bint32_value\x18\x02 \x01(\x05\x12\x13\n\x0bint64_value\x18\x03 \x01(\x03\x12\x14\n\x0cuint32_value\x18\x04 \x01(\r\x12\x14\n\x0cuint64_value\x18\x05 \x01(\x04\x12\x13\n\x0b\x66loat_value\x18\x06 \x01(\x02\x12\x14\n\x0c\x64ouble_value\x18\x07 \x01(\x01\x12\x14\n\x0cstring_value\x18\x08 \x01(\t\x12\x13\n\x0b\x62ytes_value\x18\t \x01(\x0c\x12$\n\nenum_value\x18\n \x01(\x0e\x32\x10.proto3.EnumType\x12*\n\rmessage_value\x18\x0b \x01(\x0b\x32\x13.proto3.MessageType\x12\x1b\n\x13repeated_bool_value\x18\x15 \x03(\x08\x12\x1c\n\x14repeated_int32_value\x18\x16 \x03(\x05\x12\x1c\n\x14repeated_int64_value\x18\x17 \x03(\x03\x12\x1d\n\x15repeated_uint32_value\x18\x18 \x03(\r\x12\x1d\n\x15repeated_uint64_value\x18\x19 \x03(\x04\x12\x1c\n\x14repeated_float_value\x18\x1a \x03(\x02\x12\x1d\n\x15repeated_double_value\x18\x1b \x03(\x01\x12\x1d\n\x15repeated_string_value\x18\x1c \x03(\t\x12\x1c\n\x14repeated_bytes_value\x18\x1d \x03(\x0c\x12-\n\x13repeated_enum_value\x18\x1e \x03(\x0e\x32\x10.proto3.EnumType\x12\x33\n\x16repeated_message_value\x18\x1f \x03(\x0b\x32\x13.proto3.MessageType\"\x8c\x02\n\tTestOneof\x12\x1b\n\x11oneof_int32_value\x18\x01 \x01(\x05H\x00\x12\x1c\n\x12oneof_string_value\x18\x02 \x01(\tH\x00\x12\x1b\n\x11oneof_bytes_value\x18\x03 \x01(\x0cH\x00\x12,\n\x10oneof_enum_value\x18\x04 \x01(\x0e\x32\x10.proto3.EnumTypeH\x00\x12\x32\n\x13oneof_message_value\x18\x05 \x01(\x0b\x32\x13.proto3.MessageTypeH\x00\x12\x36\n\x10oneof_null_value\x18\x06 \x01(\x0e\x32\x1a.google.protobuf.NullValueH\x00\x42\r\n\x0boneof_value\"\xe1\x04\n\x07TestMap\x12.\n\x08\x62ool_map\x18\x01 \x03(\x0b\x32\x1c.proto3.TestMap.BoolMapEntry\x12\x30\n\tint32_map\x18\x02 \x03(\x0b\x32\x1d.proto3.TestMap.Int32MapEntry\x12\x30\n\tint64_map\x18\x03 \x03(\x0b\x32\x1d.proto3.TestMap.Int64MapEntry\x12\x32\n\nuint32_map\x18\x04 \x03(\x0b\x32\x1e.proto3.TestMap.Uint32MapEntry\x12\x32\n\nuint64_map\x18\x05 \x03(\x0b\x32\x1e.proto3.TestMap.Uint64MapEntry\x12\x32\n\nstring_map\x18\x06 \x03(\x0b\x32\x1e.proto3.TestMap.StringMapEntry\x1a.\n\x0c\x42oolMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\x08\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\x1a/\n\rInt32MapEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\x1a/\n\rInt64MapEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\x1a\x30\n\x0eUint32MapEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\x1a\x30\n\x0eUint64MapEntry\x12\x0b\n\x03key\x18\x01 \x01(\x04\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\x1a\x30\n\x0eStringMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\"\x85\x06\n\rTestNestedMap\x12\x34\n\x08\x62ool_map\x18\x01 \x03(\x0b\x32\".proto3.TestNestedMap.BoolMapEntry\x12\x36\n\tint32_map\x18\x02 \x03(\x0b\x32#.proto3.TestNestedMap.Int32MapEntry\x12\x36\n\tint64_map\x18\x03 \x03(\x0b\x32#.proto3.TestNestedMap.Int64MapEntry\x12\x38\n\nuint32_map\x18\x04 \x03(\x0b\x32$.proto3.TestNestedMap.Uint32MapEntry\x12\x38\n\nuint64_map\x18\x05 \x03(\x0b\x32$.proto3.TestNestedMap.Uint64MapEntry\x12\x38\n\nstring_map\x18\x06 \x03(\x0b\x32$.proto3.TestNestedMap.StringMapEntry\x12\x32\n\x07map_map\x18\x07 \x03(\x0b\x32!.proto3.TestNestedMap.MapMapEntry\x1a.\n\x0c\x42oolMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\x08\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\x1a/\n\rInt32MapEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\x1a/\n\rInt64MapEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\x1a\x30\n\x0eUint32MapEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\x1a\x30\n\x0eUint64MapEntry\x12\x0b\n\x03key\x18\x01 \x01(\x04\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\x1a\x30\n\x0eStringMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\x1a\x44\n\x0bMapMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12$\n\x05value\x18\x02 \x01(\x0b\x32\x15.proto3.TestNestedMap:\x02\x38\x01\"{\n\rTestStringMap\x12\x38\n\nstring_map\x18\x01 \x03(\x0b\x32$.proto3.TestStringMap.StringMapEntry\x1a\x30\n\x0eStringMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xee\x07\n\x0bTestWrapper\x12.\n\nbool_value\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x30\n\x0bint32_value\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12\x30\n\x0bint64_value\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x32\n\x0cuint32_value\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x32\n\x0cuint64_value\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12\x30\n\x0b\x66loat_value\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12\x32\n\x0c\x64ouble_value\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x32\n\x0cstring_value\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x30\n\x0b\x62ytes_value\x18\t \x01(\x0b\x32\x1b.google.protobuf.BytesValue\x12\x37\n\x13repeated_bool_value\x18\x0b \x03(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x39\n\x14repeated_int32_value\x18\x0c \x03(\x0b\x32\x1b.google.protobuf.Int32Value\x12\x39\n\x14repeated_int64_value\x18\r \x03(\x0b\x32\x1b.google.protobuf.Int64Value\x12;\n\x15repeated_uint32_value\x18\x0e \x03(\x0b\x32\x1c.google.protobuf.UInt32Value\x12;\n\x15repeated_uint64_value\x18\x0f \x03(\x0b\x32\x1c.google.protobuf.UInt64Value\x12\x39\n\x14repeated_float_value\x18\x10 \x03(\x0b\x32\x1b.google.protobuf.FloatValue\x12;\n\x15repeated_double_value\x18\x11 \x03(\x0b\x32\x1c.google.protobuf.DoubleValue\x12;\n\x15repeated_string_value\x18\x12 \x03(\x0b\x32\x1c.google.protobuf.StringValue\x12\x39\n\x14repeated_bytes_value\x18\x13 \x03(\x0b\x32\x1b.google.protobuf.BytesValue\"n\n\rTestTimestamp\x12)\n\x05value\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x0erepeated_value\x18\x02 \x03(\x0b\x32\x1a.google.protobuf.Timestamp\"k\n\x0cTestDuration\x12(\n\x05value\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x31\n\x0erepeated_value\x18\x02 \x03(\x0b\x32\x19.google.protobuf.Duration\":\n\rTestFieldMask\x12)\n\x05value\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"e\n\nTestStruct\x12&\n\x05value\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\x12/\n\x0erepeated_value\x18\x02 \x03(\x0b\x32\x17.google.protobuf.Struct\"\\\n\x07TestAny\x12#\n\x05value\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12,\n\x0erepeated_value\x18\x02 \x03(\x0b\x32\x14.google.protobuf.Any\"b\n\tTestValue\x12%\n\x05value\x18\x01 \x01(\x0b\x32\x16.google.protobuf.Value\x12.\n\x0erepeated_value\x18\x02 \x03(\x0b\x32\x16.google.protobuf.Value\"n\n\rTestListValue\x12)\n\x05value\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12\x32\n\x0erepeated_value\x18\x02 \x03(\x0b\x32\x1a.google.protobuf.ListValue\"\x89\x01\n\rTestBoolValue\x12\x12\n\nbool_value\x18\x01 \x01(\x08\x12\x34\n\x08\x62ool_map\x18\x02 \x03(\x0b\x32\".proto3.TestBoolValue.BoolMapEntry\x1a.\n\x0c\x42oolMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\x08\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\"x\n\rTestNullValue\x12.\n\nnull_value\x18\x14 \x01(\x0e\x32\x1a.google.protobuf.NullValue\x12\x37\n\x13repeated_null_value\x18\x15 \x03(\x0e\x32\x1a.google.protobuf.NullValue\"+\n\x12TestCustomJsonName\x12\x15\n\x05value\x18\x01 \x01(\x05R\x06@value\"\xaf\x01\n\x0cTestEvilJson\x12#\n\rregular_value\x18\x01 \x01(\x05R\x0cregular_name\x12\x19\n\x06script\x18\x02 \x01(\x05R\t</script>\x12!\n\x06quotes\x18\x03 \x01(\x05R\x11unbalanced\"quotes\x12<\n\x11script_and_quotes\x18\x04 \x01(\x05R!\"<script>alert(\'hello!);</script>\"J\n\x0eTestExtensions\x12\x38\n\nextensions\x18\x01 \x01(\x0b\x32$.protobuf_unittest.TestAllExtensions\"\x84\x01\n\rTestEnumValue\x12%\n\x0b\x65num_value1\x18\x01 \x01(\x0e\x32\x10.proto3.EnumType\x12%\n\x0b\x65num_value2\x18\x02 \x01(\x0e\x32\x10.proto3.EnumType\x12%\n\x0b\x65num_value3\x18\x03 \x01(\x0e\x32\x10.proto3.EnumType\"\xeb\x04\n\rMapsTestCases\x12#\n\tempty_map\x18\x01 \x01(\x0b\x32\x10.proto3.EmptyMap\x12*\n\rstring_to_int\x18\x02 \x01(\x0b\x32\x13.proto3.StringtoInt\x12*\n\rint_to_string\x18\x03 \x01(\x0b\x32\x13.proto3.IntToString\x12\x1e\n\x06mixed1\x18\x04 \x01(\x0b\x32\x0e.proto3.Mixed1\x12\x1e\n\x06mixed2\x18\x05 \x01(\x0b\x32\x0e.proto3.Mixed2\x12,\n\x0emap_of_objects\x18\x06 \x01(\x0b\x32\x14.proto3.MapOfObjects\x12\x35\n\x18\x65mpty_key_string_to_int1\x18\x07 \x01(\x0b\x32\x13.proto3.StringtoInt\x12\x35\n\x18\x65mpty_key_string_to_int2\x18\x08 \x01(\x0b\x32\x13.proto3.StringtoInt\x12\x35\n\x18\x65mpty_key_string_to_int3\x18\t \x01(\x0b\x32\x13.proto3.StringtoInt\x12\x36\n\x18\x65mpty_key_bool_to_string\x18\n \x01(\x0b\x32\x14.proto3.BoolToString\x12\x34\n\x17\x65mpty_key_int_to_string\x18\x0b \x01(\x0b\x32\x13.proto3.IntToString\x12\'\n\x0f\x65mpty_key_mixed\x18\x0c \x01(\x0b\x32\x0e.proto3.Mixed1\x12\x33\n\x15\x65mpty_key_map_objects\x18\r \x01(\x0b\x32\x14.proto3.MapOfObjects\"^\n\x08\x45mptyMap\x12&\n\x03map\x18\x01 \x03(\x0b\x32\x19.proto3.EmptyMap.MapEntry\x1a*\n\x08MapEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\"d\n\x0bStringtoInt\x12)\n\x03map\x18\x01 \x03(\x0b\x32\x1c.proto3.StringtoInt.MapEntry\x1a*\n\x08MapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\"d\n\x0bIntToString\x12)\n\x03map\x18\x01 \x03(\x0b\x32\x1c.proto3.IntToString.MapEntry\x1a*\n\x08MapEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"f\n\x0c\x42oolToString\x12*\n\x03map\x18\x01 \x03(\x0b\x32\x1d.proto3.BoolToString.MapEntry\x1a*\n\x08MapEntry\x12\x0b\n\x03key\x18\x01 \x01(\x08\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"g\n\x06Mixed1\x12\x0b\n\x03msg\x18\x01 \x01(\t\x12$\n\x03map\x18\x02 \x03(\x0b\x32\x17.proto3.Mixed1.MapEntry\x1a*\n\x08MapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02:\x02\x38\x01\"\x9d\x01\n\x06Mixed2\x12$\n\x03map\x18\x01 \x03(\x0b\x32\x17.proto3.Mixed2.MapEntry\x12\x1c\n\x02\x65\x65\x18\x02 \x01(\x0e\x32\x10.proto3.Mixed2.E\x1a*\n\x08MapEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\"#\n\x01\x45\x12\x06\n\x02\x45\x30\x10\x00\x12\x06\n\x02\x45\x31\x10\x01\x12\x06\n\x02\x45\x32\x10\x02\x12\x06\n\x02\x45\x33\x10\x03\"\x97\x01\n\x0cMapOfObjects\x12*\n\x03map\x18\x01 \x03(\x0b\x32\x1d.proto3.MapOfObjects.MapEntry\x1a\x17\n\x01M\x12\x12\n\ninner_text\x18\x01 \x01(\t\x1a\x42\n\x08MapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12%\n\x05value\x18\x02 \x01(\x0b\x32\x16.proto3.MapOfObjects.M:\x02\x38\x01\"\xf8\x01\n\x05MapIn\x12\r\n\x05other\x18\x01 \x01(\t\x12\x0e\n\x06things\x18\x02 \x03(\t\x12.\n\tmap_input\x18\x03 \x03(\x0b\x32\x1b.proto3.MapIn.MapInputEntry\x12*\n\x07map_any\x18\x04 \x03(\x0b\x32\x19.proto3.MapIn.MapAnyEntry\x1a/\n\rMapInputEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x43\n\x0bMapAnyEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any:\x02\x38\x01\"\x87\x03\n\x06MapOut\x12&\n\x04map1\x18\x01 \x03(\x0b\x32\x18.proto3.MapOut.Map1Entry\x12&\n\x04map2\x18\x02 \x03(\x0b\x32\x18.proto3.MapOut.Map2Entry\x12&\n\x04map3\x18\x03 \x03(\x0b\x32\x18.proto3.MapOut.Map3Entry\x12&\n\x04map4\x18\x05 \x03(\x0b\x32\x18.proto3.MapOut.Map4Entry\x12\x0b\n\x03\x62\x61r\x18\x04 \x01(\t\x1a\x39\n\tMap1Entry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1b\n\x05value\x18\x02 \x01(\x0b\x32\x0c.proto3.MapM:\x02\x38\x01\x1a;\n\tMap2Entry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1d\n\x05value\x18\x02 \x01(\x0b\x32\x0e.proto3.MapOut:\x02\x38\x01\x1a+\n\tMap3Entry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tMap4Entry\x12\x0b\n\x03key\x18\x01 \x01(\x08\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa9\x03\n\x10MapOutWireFormat\x12\x30\n\x04map1\x18\x01 \x03(\x0b\x32\".proto3.MapOutWireFormat.Map1Entry\x12\x30\n\x04map2\x18\x02 \x03(\x0b\x32\".proto3.MapOutWireFormat.Map2Entry\x12\x30\n\x04map3\x18\x03 \x03(\x0b\x32\".proto3.MapOutWireFormat.Map3Entry\x12\x30\n\x04map4\x18\x05 \x03(\x0b\x32\".proto3.MapOutWireFormat.Map4Entry\x12\x0b\n\x03\x62\x61r\x18\x04 \x01(\t\x1a\x35\n\tMap1Entry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1b\n\x05value\x18\x02 \x01(\x0b\x32\x0c.proto3.MapM\x1a\x37\n\tMap2Entry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1d\n\x05value\x18\x02 \x01(\x0b\x32\x0e.proto3.MapOut\x1a\'\n\tMap3Entry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\t\x1a\'\n\tMap4Entry\x12\x0b\n\x03key\x18\x01 \x01(\x08\x12\r\n\x05value\x18\x02 \x01(\t\"\x13\n\x04MapM\x12\x0b\n\x03\x66oo\x18\x01 \x01(\t*)\n\x08\x45numType\x12\x07\n\x03\x46OO\x10\x00\x12\x07\n\x03\x42\x41R\x10\x01\x12\x0b\n\x07TLSv1_2\x10\x02\x42,\n\x18\x63om.google.protobuf.utilB\x10JsonFormatProto3b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.protobuf.util.json_format_proto3_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\030com.google.protobuf.utilB\020JsonFormatProto3'
  _globals['_TESTMAP_BOOLMAPENTRY']._options = None
  _globals['_TESTMAP_BOOLMAPENTRY']._serialized_options = b'8\001'
  _globals['_TESTMAP_INT32MAPENTRY']._options = None
  _globals['_TESTMAP_INT32MAPENTRY']._serialized_options = b'8\001'
  _globals['_TESTMAP_INT64MAPENTRY']._options = None
  _globals['_TESTMAP_INT64MAPENTRY']._serialized_options = b'8\001'
  _globals['_TESTMAP_UINT32MAPENTRY']._options = None
  _globals['_TESTMAP_UINT32MAPENTRY']._serialized_options = b'8\001'
  _globals['_TESTMAP_UINT64MAPENTRY']._options = None
  _globals['_TESTMAP_UINT64MAPENTRY']._serialized_options = b'8\001'
  _globals['_TESTMAP_STRINGMAPENTRY']._options = None
  _globals['_TESTMAP_STRINGMAPENTRY']._serialized_options = b'8\001'
  _globals['_TESTNESTEDMAP_BOOLMAPENTRY']._options = None
  _globals['_TESTNESTEDMAP_BOOLMAPENTRY']._serialized_options = b'8\001'
  _globals['_TESTNESTEDMAP_INT32MAPENTRY']._options = None
  _globals['_TESTNESTEDMAP_INT32MAPENTRY']._serialized_options = b'8\001'
  _globals['_TESTNESTEDMAP_INT64MAPENTRY']._options = None
  _globals['_TESTNESTEDMAP_INT64MAPENTRY']._serialized_options = b'8\001'
  _globals['_TESTNESTEDMAP_UINT32MAPENTRY']._options = None
  _globals['_TESTNESTEDMAP_UINT32MAPENTRY']._serialized_options = b'8\001'
  _globals['_TESTNESTEDMAP_UINT64MAPENTRY']._options = None
  _globals['_TESTNESTEDMAP_UINT64MAPENTRY']._serialized_options = b'8\001'
  _globals['_TESTNESTEDMAP_STRINGMAPENTRY']._options = None
  _globals['_TESTNESTEDMAP_STRINGMAPENTRY']._serialized_options = b'8\001'
  _globals['_TESTNESTEDMAP_MAPMAPENTRY']._options = None
  _globals['_TESTNESTEDMAP_MAPMAPENTRY']._serialized_options = b'8\001'
  _globals['_TESTSTRINGMAP_STRINGMAPENTRY']._options = None
  _globals['_TESTSTRINGMAP_STRINGMAPENTRY']._serialized_options = b'8\001'
  _globals['_TESTBOOLVALUE_BOOLMAPENTRY']._options = None
  _globals['_TESTBOOLVALUE_BOOLMAPENTRY']._serialized_options = b'8\001'
  _globals['_EMPTYMAP_MAPENTRY']._options = None
  _globals['_EMPTYMAP_MAPENTRY']._serialized_options = b'8\001'
  _globals['_STRINGTOINT_MAPENTRY']._options = None
  _globals['_STRINGTOINT_MAPENTRY']._serialized_options = b'8\001'
  _globals['_INTTOSTRING_MAPENTRY']._options = None
  _globals['_INTTOSTRING_MAPENTRY']._serialized_options = b'8\001'
  _globals['_BOOLTOSTRING_MAPENTRY']._options = None
  _globals['_BOOLTOSTRING_MAPENTRY']._serialized_options = b'8\001'
  _globals['_MIXED1_MAPENTRY']._options = None
  _globals['_MIXED1_MAPENTRY']._serialized_options = b'8\001'
  _globals['_MIXED2_MAPENTRY']._options = None
  _globals['_MIXED2_MAPENTRY']._serialized_options = b'8\001'
  _globals['_MAPOFOBJECTS_MAPENTRY']._options = None
  _globals['_MAPOFOBJECTS_MAPENTRY']._serialized_options = b'8\001'
  _globals['_MAPIN_MAPINPUTENTRY']._options = None
  _globals['_MAPIN_MAPINPUTENTRY']._serialized_options = b'8\001'
  _globals['_MAPIN_MAPANYENTRY']._options = None
  _globals['_MAPIN_MAPANYENTRY']._serialized_options = b'8\001'
  _globals['_MAPOUT_MAP1ENTRY']._options = None
  _globals['_MAPOUT_MAP1ENTRY']._serialized_options = b'8\001'
  _globals['_MAPOUT_MAP2ENTRY']._options = None
  _globals['_MAPOUT_MAP2ENTRY']._serialized_options = b'8\001'
  _globals['_MAPOUT_MAP3ENTRY']._options = None
  _globals['_MAPOUT_MAP3ENTRY']._serialized_options = b'8\001'
  _globals['_MAPOUT_MAP4ENTRY']._options = None
  _globals['_MAPOUT_MAP4ENTRY']._serialized_options = b'8\001'
  _globals['_ENUMTYPE']._serialized_start=7688
  _globals['_ENUMTYPE']._serialized_end=7729
  _globals['_MESSAGETYPE']._serialized_start=277
  _globals['_MESSAGETYPE']._serialized_end=305
  _globals['_TESTMESSAGE']._serialized_start=308
  _globals['_TESTMESSAGE']._serialized_end=968
  _globals['_TESTONEOF']._serialized_start=971
  _globals['_TESTONEOF']._serialized_end=1239
  _globals['_TESTMAP']._serialized_start=1242
  _globals['_TESTMAP']._serialized_end=1851
  _globals['_TESTMAP_BOOLMAPENTRY']._serialized_start=1557
  _globals['_TESTMAP_BOOLMAPENTRY']._serialized_end=1603
  _globals['_TESTMAP_INT32MAPENTRY']._serialized_start=1605
  _globals['_TESTMAP_INT32MAPENTRY']._serialized_end=1652
  _globals['_TESTMAP_INT64MAPENTRY']._serialized_start=1654
  _globals['_TESTMAP_INT64MAPENTRY']._serialized_end=1701
  _globals['_TESTMAP_UINT32MAPENTRY']._serialized_start=1703
  _globals['_TESTMAP_UINT32MAPENTRY']._serialized_end=1751
  _globals['_TESTMAP_UINT64MAPENTRY']._serialized_start=1753
  _globals['_TESTMAP_UINT64MAPENTRY']._serialized_end=1801
  _globals['_TESTMAP_STRINGMAPENTRY']._serialized_start=1803
  _globals['_TESTMAP_STRINGMAPENTRY']._serialized_end=1851
  _globals['_TESTNESTEDMAP']._serialized_start=1854
  _globals['_TESTNESTEDMAP']._serialized_end=2627
  _globals['_TESTNESTEDMAP_BOOLMAPENTRY']._serialized_start=1557
  _globals['_TESTNESTEDMAP_BOOLMAPENTRY']._serialized_end=1603
  _globals['_TESTNESTEDMAP_INT32MAPENTRY']._serialized_start=1605
  _globals['_TESTNESTEDMAP_INT32MAPENTRY']._serialized_end=1652
  _globals['_TESTNESTEDMAP_INT64MAPENTRY']._serialized_start=1654
  _globals['_TESTNESTEDMAP_INT64MAPENTRY']._serialized_end=1701
  _globals['_TESTNESTEDMAP_UINT32MAPENTRY']._serialized_start=1703
  _globals['_TESTNESTEDMAP_UINT32MAPENTRY']._serialized_end=1751
  _globals['_TESTNESTEDMAP_UINT64MAPENTRY']._serialized_start=1753
  _globals['_TESTNESTEDMAP_UINT64MAPENTRY']._serialized_end=1801
  _globals['_TESTNESTEDMAP_STRINGMAPENTRY']._serialized_start=1803
  _globals['_TESTNESTEDMAP_STRINGMAPENTRY']._serialized_end=1851
  _globals['_TESTNESTEDMAP_MAPMAPENTRY']._serialized_start=2559
  _globals['_TESTNESTEDMAP_MAPMAPENTRY']._serialized_end=2627
  _globals['_TESTSTRINGMAP']._serialized_start=2629
  _globals['_TESTSTRINGMAP']._serialized_end=2752
  _globals['_TESTSTRINGMAP_STRINGMAPENTRY']._serialized_start=2704
  _globals['_TESTSTRINGMAP_STRINGMAPENTRY']._serialized_end=2752
  _globals['_TESTWRAPPER']._serialized_start=2755
  _globals['_TESTWRAPPER']._serialized_end=3761
  _globals['_TESTTIMESTAMP']._serialized_start=3763
  _globals['_TESTTIMESTAMP']._serialized_end=3873
  _globals['_TESTDURATION']._serialized_start=3875
  _globals['_TESTDURATION']._serialized_end=3982
  _globals['_TESTFIELDMASK']._serialized_start=3984
  _globals['_TESTFIELDMASK']._serialized_end=4042
  _globals['_TESTSTRUCT']._serialized_start=4044
  _globals['_TESTSTRUCT']._serialized_end=4145
  _globals['_TESTANY']._serialized_start=4147
  _globals['_TESTANY']._serialized_end=4239
  _globals['_TESTVALUE']._serialized_start=4241
  _globals['_TESTVALUE']._serialized_end=4339
  _globals['_TESTLISTVALUE']._serialized_start=4341
  _globals['_TESTLISTVALUE']._serialized_end=4451
  _globals['_TESTBOOLVALUE']._serialized_start=4454
  _globals['_TESTBOOLVALUE']._serialized_end=4591
  _globals['_TESTBOOLVALUE_BOOLMAPENTRY']._serialized_start=1557
  _globals['_TESTBOOLVALUE_BOOLMAPENTRY']._serialized_end=1603
  _globals['_TESTNULLVALUE']._serialized_start=4593
  _globals['_TESTNULLVALUE']._serialized_end=4713
  _globals['_TESTCUSTOMJSONNAME']._serialized_start=4715
  _globals['_TESTCUSTOMJSONNAME']._serialized_end=4758
  _globals['_TESTEVILJSON']._serialized_start=4761
  _globals['_TESTEVILJSON']._serialized_end=4936
  _globals['_TESTEXTENSIONS']._serialized_start=4938
  _globals['_TESTEXTENSIONS']._serialized_end=5012
  _globals['_TESTENUMVALUE']._serialized_start=5015
  _globals['_TESTENUMVALUE']._serialized_end=5147
  _globals['_MAPSTESTCASES']._serialized_start=5150
  _globals['_MAPSTESTCASES']._serialized_end=5769
  _globals['_EMPTYMAP']._serialized_start=5771
  _globals['_EMPTYMAP']._serialized_end=5865
  _globals['_EMPTYMAP_MAPENTRY']._serialized_start=5823
  _globals['_EMPTYMAP_MAPENTRY']._serialized_end=5865
  _globals['_STRINGTOINT']._serialized_start=5867
  _globals['_STRINGTOINT']._serialized_end=5967
  _globals['_STRINGTOINT_MAPENTRY']._serialized_start=5925
  _globals['_STRINGTOINT_MAPENTRY']._serialized_end=5967
  _globals['_INTTOSTRING']._serialized_start=5969
  _globals['_INTTOSTRING']._serialized_end=6069
  _globals['_INTTOSTRING_MAPENTRY']._serialized_start=6027
  _globals['_INTTOSTRING_MAPENTRY']._serialized_end=6069
  _globals['_BOOLTOSTRING']._serialized_start=6071
  _globals['_BOOLTOSTRING']._serialized_end=6173
  _globals['_BOOLTOSTRING_MAPENTRY']._serialized_start=6131
  _globals['_BOOLTOSTRING_MAPENTRY']._serialized_end=6173
  _globals['_MIXED1']._serialized_start=6175
  _globals['_MIXED1']._serialized_end=6278
  _globals['_MIXED1_MAPENTRY']._serialized_start=6236
  _globals['_MIXED1_MAPENTRY']._serialized_end=6278
  _globals['_MIXED2']._serialized_start=6281
  _globals['_MIXED2']._serialized_end=6438
  _globals['_MIXED2_MAPENTRY']._serialized_start=6359
  _globals['_MIXED2_MAPENTRY']._serialized_end=6401
  _globals['_MIXED2_E']._serialized_start=6403
  _globals['_MIXED2_E']._serialized_end=6438
  _globals['_MAPOFOBJECTS']._serialized_start=6441
  _globals['_MAPOFOBJECTS']._serialized_end=6592
  _globals['_MAPOFOBJECTS_M']._serialized_start=6501
  _globals['_MAPOFOBJECTS_M']._serialized_end=6524
  _globals['_MAPOFOBJECTS_MAPENTRY']._serialized_start=6526
  _globals['_MAPOFOBJECTS_MAPENTRY']._serialized_end=6592
  _globals['_MAPIN']._serialized_start=6595
  _globals['_MAPIN']._serialized_end=6843
  _globals['_MAPIN_MAPINPUTENTRY']._serialized_start=6727
  _globals['_MAPIN_MAPINPUTENTRY']._serialized_end=6774
  _globals['_MAPIN_MAPANYENTRY']._serialized_start=6776
  _globals['_MAPIN_MAPANYENTRY']._serialized_end=6843
  _globals['_MAPOUT']._serialized_start=6846
  _globals['_MAPOUT']._serialized_end=7237
  _globals['_MAPOUT_MAP1ENTRY']._serialized_start=7029
  _globals['_MAPOUT_MAP1ENTRY']._serialized_end=7086
  _globals['_MAPOUT_MAP2ENTRY']._serialized_start=7088
  _globals['_MAPOUT_MAP2ENTRY']._serialized_end=7147
  _globals['_MAPOUT_MAP3ENTRY']._serialized_start=7149
  _globals['_MAPOUT_MAP3ENTRY']._serialized_end=7192
  _globals['_MAPOUT_MAP4ENTRY']._serialized_start=7194
  _globals['_MAPOUT_MAP4ENTRY']._serialized_end=7237
  _globals['_MAPOUTWIREFORMAT']._serialized_start=7240
  _globals['_MAPOUTWIREFORMAT']._serialized_end=7665
  _globals['_MAPOUTWIREFORMAT_MAP1ENTRY']._serialized_start=7029
  _globals['_MAPOUTWIREFORMAT_MAP1ENTRY']._serialized_end=7082
  _globals['_MAPOUTWIREFORMAT_MAP2ENTRY']._serialized_start=7088
  _globals['_MAPOUTWIREFORMAT_MAP2ENTRY']._serialized_end=7143
  _globals['_MAPOUTWIREFORMAT_MAP3ENTRY']._serialized_start=7149
  _globals['_MAPOUTWIREFORMAT_MAP3ENTRY']._serialized_end=7188
  _globals['_MAPOUTWIREFORMAT_MAP4ENTRY']._serialized_start=7194
  _globals['_MAPOUTWIREFORMAT_MAP4ENTRY']._serialized_end=7233
  _globals['_MAPM']._serialized_start=7667
  _globals['_MAPM']._serialized_end=7686
# @@protoc_insertion_point(module_scope)
